Armadillo — excentury 0.2 documentation

# Armadillo

Excentury supports the use of armadillos datatypes. Armadillo is a C++ linear algebra library. See more information on the library at http://arma.sourceforge.net/.

To see an example see the following directory

> https://github.com/jmlopez-rod/excentury/tree/master/tests

There we can find `xcpp/arma.xcpp` which contains an example. We also need to consider the configuration file `xcpp.config` since it contains information on how to compile excentury files using the armadillo library.